Development
***********

To get started developing, have a look at our
:ref:`contribution guidelines <contributing>`.
This chapter describes how to implement the most commonly contributed new
features.

.. toctree::
   :maxdepth: 1

    Preprocessor function <preprocessor_function>
    Fixing data <fixing_data>
    Deriving a variable <derivation>
